/*
Copyright (C) 2006 Parallel Realities

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#ifdef __unix__
	#include <sys/stat.h>
	#include <pwd.h>
	#include <unistd.h>
	#include <errno.h>
#endif

#include "headers.h"

extern List *loadProperties(const char *filename, bool required);
extern void renderScaledTexture(Texture *texture);

extern Audio *audio;
extern EntityManager *entityManager;
extern Engine *engine;
extern Game *game;
extern Graphics *graphics;
extern ModelManager *modelManager;
extern Mouse *mouse;
extern Pak *pak;
extern TextureManager *textureManager;
extern UIManager *uiManager;
